dnl $Id: aclocal.m4,v 1.1 1999/04/25 23:04:46 waite Exp $
dnl
dnl Configuration Macros.
dnl 
dnl These macros extend capabilities of Autoconf or replace existing
dnl macros in order to remove some problems.
dnl

dnl #############################################################################
dnl Macro for Creating a Logfile Message
dnl
dnl Macro-Name:		ELI_MSG_LOG
dnl
dnl Arguments:		$1:	Message to log, without "
dnl
dnl Preconditions:	none
dnl
dnl Postconditions:	message had been appended to logfile
dnl
dnl Comments:		none

AC_DEFUN(ELI_MSG_LOG, 
[
echo "  $1" 1>&AC_FD_CC
])

dnl #############################################################################
dnl Macro for adding a switch to a linker commandline for Solaris:
dnl For each -L option under Solaris a equal -R option is required because
dnl Solaris does not search dynamic libraries in the Pathes that were specified
dnl with -L automatically.
dnl
dnl Macro-Name:		ELI_LIB_SOLARIS
dnl
dnl Arguments:		Name of environment-variable that should be changed.
dnl
dnl Postconditions:	
dnl
dnl Comments:		Library-Path-Specification must be attached to the
dnl			-L-Option without a separating space.

AC_DEFUN(ELI_LIB_SOLARIS,
[
dnl First check, if under Solaris.

if test "`(uname) 2>/dev/null`" = SunOS && uname -r | grep '^5' >/dev/null; then
	eli_lib_solaris=''
	for option in ${$1}; do
		if echo $option | grep '^-L' >/dev/null; then
			eli_lib_solaris_more=`echo $option | sed 's/^-L//'`
			if test "$eli_lib_solaris" = ""; then
				eli_lib_solaris=$eli_lib_solaris_more
			else
				eli_lib_solaris="$eli_lib_solaris:$eli_lib_solaris_more"
			fi
		fi
	done
	if test "$eli_lib_solaris" != ""; then
		$1=${$1}" -R $eli_lib_solaris"
	fi
fi
])
 
dnl #############################################################################
dnl Macro for finding a good cpp-processor.
dnl
dnl Macro-Name:		ELI_PROG_CPP
dnl
dnl Arguments:		none
dnl
dnl Preconditions:	User can specify a processor in environment-variable CPP.
dnl
dnl Postconditions:	substitutes CPPPROG and CPPFLAGS.
dnl
dnl Comments:		Using the C-Compiler does not work, since only *.c-files
dnl			can be processed with it.
dnl
dnl			Call this macro before AC_PROG_CPP and AC_PROG_CC
dnl		
dnl			Sets variable eli_no_cpp=yes, if no good cpp was found.
dnl
dnl			Calling ELI_PROG_CPP does not replace a call to AC_PROG_CPP!

AC_DEFUN(ELI_PROG_CPP,
[
CPPPROG="$CPP"
eli_no_cpp=

# On Suns, sometimes $CPP names a directory.
if test -n "$CPPPROG" && test -d "$CPPPROG"; then
	CPPPROG=
fi

# If CPP does not point to an existing file, remove it.
if test -n "$CPPPROG" && test ! -f "$CPPPROG"; then
	CPPPROG=
fi

if test -z "$CPPPROG"; then
	AC_PATH_PROG(CPPPROG, cpp,,$PATH:/lib:/usr/bin:/usr/ccs/lib)
	if test -z "$CPPPROG"; then
		eli_no_cpp=yes
	fi
fi
AC_SUBST(CPPPROG)

dnl -- Figure out, how to call cpp

AC_MSG_CHECKING([whether the cpp ($CPPPROG) works])

CPPFLAGS=
if test "axxxa" != "a`echo XXX| $CPPPROG $CPPFLAGS -P -C -DXXX=xxx 2>/dev/null`a"; then
   	# CPP seems to append something to it's output
	# See, if that goes away when including '-traditional'
   	CPPFLAGS='-traditional'
   	if test "axxxa" != "a`echo XXX| $CPPPROG $CPPFLAGS -P -C -DXXX=xxx 2>/dev/null`a" 
	then
		# No, that did not go away. It does not work properly.
		eli_no_cpp=yes
   	fi
fi

AC_SUBST(CPPFLAGS)
AC_MSG_RESULT(yes)
])


dnl #############################################################################
dnl Macro for finding a good C compiler
dnl
dnl Macro-Name:		ELI_PROG_CC
dnl
dnl Arguments:		none
dnl
dnl Preconditions:	User can specify a compiler in environment-variable CC.
dnl
dnl Postconditions:	substitutes CC and sets CFLAGS and GCC.
dnl
dnl Comments:		This is just like AC_PROG_CC except that cc is
dnl			preferred over gcc.

AC_DEFUN(ELI_PROG_CC,
[AC_BEFORE([$0], [AC_PROG_CPP])dnl
AC_CHECK_PROG(CC, cc, cc, , , /usr/ucb/cc)
if test -z "$CC"; then
  AC_CHECK_PROG(CC, gcc, gcc)
  test -z "$CC" && AC_MSG_ERROR([no acceptable cc found in \$PATH])
fi

AC_CACHE_CHECK(whether we are using GNU C, ac_cv_prog_gcc,
[dnl The semicolon is to pacify NeXT's syntax-checking cpp.
cat > conftest.c <<EOF
#ifdef __GNUC__
  yes;
#endif
EOF
if AC_TRY_COMMAND(${CC-cc} -E conftest.c) | egrep yes >/dev/null 2>&1; then
  ac_cv_prog_gcc=yes
else
  ac_cv_prog_gcc=no
fi])
if test $ac_cv_prog_gcc = yes; then
  GCC=yes
  if test "${CFLAGS+set}" != set; then
    AC_CACHE_CHECK(whether ${CC-cc} accepts -g, ac_cv_prog_gcc_g,
[echo 'void f(){}' > conftest.c
if test -z "`${CC-cc} -g -c conftest.c 2>&1`"; then
  ac_cv_prog_gcc_g=yes
else
  ac_cv_prog_gcc_g=no
fi
rm -f conftest*
])
    if test $ac_cv_prog_gcc_g = yes; then
      CFLAGS="-g -O"
    else
      CFLAGS="-O"
    fi
  fi
else
  GCC=
  test "${CFLAGS+set}" = set || CFLAGS="-g"
fi
])
